@@ -25,7 +25,6 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-mod app;
 mod config;
 mod invidious;
 mod player;
@@ -34,18 +33,17 @@ mod songtag;
 #[cfg(feature = "mpris")]
 mod souvlaki;
 mod ui;
-mod utils;
 
-use app::App;
 use config::Termusic;
 use std::path::Path;
 
-const VERSION: &str = env!("CARGO_PKG_VERSION");
+extern crate tuirealm;
+
+use ui::{UI, VERSION};
 
 fn main() {
     let mut config = Termusic::default();
     config.load().unwrap_or_default();
-
     let mut args: Vec<String> = std::env::args().collect();
     // match args.len() {}
 
@@ -57,7 +55,7 @@ fn main() {
             "-v" | "--version" => {
                 println!("Termusic version is: {}", VERSION);
                 should_exit = true;
-            },
+            }
 
             "-h" | "--help" => {
                 println!(
@@ -69,7 +67,7 @@ directory: start termusic with directory.
 no arguments: start termusic with ~/.config/termusic/config.toml"
                 );
                 should_exit = true;
-            },
+            }
 
             _ => {
                 let p = Path::new(i);
@@ -98,7 +96,7 @@ no arguments: start termusic with ~/.config/termusic/config.toml"
                     );
                     should_exit = true;
                 }
-            },
+            }
         }
     }
 
@@ -106,8 +104,5 @@ no arguments: start termusic with ~/.config/termusic/config.toml"
         return;
     }
 
-    // glib::set_application_name("termusic");
-    // glib::set_prgname(Some("termusic"));
-    let mut app: App = App::new(config);
-    app.run();
+    UI::new(&config).run();
 }
