@@ -26,7 +26,8 @@ mod kugou;
 pub mod lrc;
 mod migu;
 mod netease;
-use crate::ui::activity::{main::UpdateComponents, tageditor::SearchLyricState};
+// use crate::ui::activity::{main::UpdateComponents, tageditor::SearchLyricState};
+use crate::ui::{model::UpdateComponents, SearchLyricState};
 use anyhow::{anyhow, bail, Result};
 use id3::{
     frame::{Lyrics, Picture, PictureType},
@@ -37,7 +38,7 @@ use std::path::{Path, PathBuf};
 use std::sync::mpsc::{self, Receiver, Sender};
 use std::thread::{self, sleep};
 use std::time::Duration;
-use ytd_rs::{Arg, ResultType, YoutubeDL};
+use ytd_rs::{Arg, YoutubeDL};
 
 #[derive(Deserialize, Serialize)]
 pub struct SongTag {
@@ -181,20 +182,20 @@ impl SongTag {
                 if let Some(lyric_id) = &self.lyric_id {
                     lyric_string = kugou_api.song_lyric(lyric_id)?;
                 }
-            },
+            }
             Some(ServiceProvider::Netease) => {
                 let mut netease_api = netease::Api::new();
                 if let Some(lyric_id) = &self.lyric_id {
                     lyric_string = netease_api.song_lyric(lyric_id)?;
                 }
-            },
+            }
             Some(ServiceProvider::Migu) => {
                 let migu_api = migu::Api::new();
                 if let Some(lyric_id) = &self.lyric_id {
                     lyric_string = migu_api.song_lyric(lyric_id)?;
                 }
-            },
-            None => {},
+            }
+            None => {}
         }
 
         Ok(lyric_string)
@@ -212,22 +213,22 @@ impl SongTag {
                         encoded_image_bytes = kugou_api.pic(p, album_id)?;
                     }
                 }
-            },
+            }
             Some(ServiceProvider::Netease) => {
                 let mut netease_api = netease::Api::new();
                 if let Some(p) = &self.pic_id {
                     encoded_image_bytes = netease_api.pic(p)?;
                 }
-            },
+            }
             Some(ServiceProvider::Migu) => {
                 let migu_api = migu::Api::new();
                 if let Some(p) = &self.song_id {
                     encoded_image_bytes = migu_api.pic(p)?;
                 }
-            },
+            }
             None => {
                 bail!("no servie provider given");
-            },
+            }
         }
 
         if encoded_image_bytes.is_empty() {
@@ -249,8 +250,14 @@ impl SongTag {
             .song_id
             .as_ref()
             .ok_or_else(|| anyhow!("error downloading because no song id is found"))?;
-        let artist = self.artist.clone().unwrap_or_else(|| "Unknown Artist".to_string());
-        let title = self.title.clone().unwrap_or_else(|| "Unknown Title".to_string());
+        let artist = self
+            .artist
+            .clone()
+            .unwrap_or_else(|| "Unknown Artist".to_string());
+        let title = self
+            .title
+            .clone()
+            .unwrap_or_else(|| "Unknown Title".to_string());
 
         let album = self.album.clone().unwrap_or_else(|| String::from("N/A"));
         let lyric = self.fetch_lyric();
@@ -266,7 +273,12 @@ impl SongTag {
             Arg::new_with_arg("--audio-format", "mp3"),
         ];
 
-        let p_full = format!("{}/{}-{}.mp3", p_parent.to_str().unwrap_or("/tmp"), artist, title);
+        let p_full = format!(
+            "{}/{}-{}.mp3",
+            p_parent.to_str().unwrap_or("/tmp"),
+            artist,
+            title
+        );
         if std::fs::remove_file(Path::new(p_full.as_str())).is_err() {}
 
         let mp3_url = self.url.clone().unwrap_or_else(|| String::from("N/A"));
@@ -280,12 +292,12 @@ impl SongTag {
                 ServiceProvider::Netease => {
                     let mut netease_api = netease::Api::new();
                     url = netease_api.song_url(song_id)?;
-                },
-                ServiceProvider::Migu => {},
+                }
+                ServiceProvider::Migu => {}
                 ServiceProvider::Kugou => {
                     let kugou_api = kugou::Api::new();
                     url = kugou_api.song_url(song_id, &album_id)?;
-                },
+                }
             }
         }
 
@@ -302,8 +314,8 @@ impl SongTag {
             let download = ytd.download();
 
             // check what the result is and print out the path to the download or the error
-            match download.result_type() {
-                ResultType::SUCCESS => {
+            match download {
+                Ok(_result) => {
                     let mut song_id3tag = Tag::new();
                     song_id3tag.set_album(album);
                     song_id3tag.set_title(title);
@@ -324,18 +336,20 @@ impl SongTag {
                     if song_id3tag.write_to_path(file, Version::Id3v24).is_ok() {
                         tx.send(UpdateComponents::DownloadSuccess).ok();
                         sleep(Duration::from_secs(5));
-                        tx.send(UpdateComponents::DownloadCompleted(Some(p_full))).ok();
+                        tx.send(UpdateComponents::DownloadCompleted(Some(file.to_string())))
+                            .ok();
                     } else {
                         tx.send(UpdateComponents::DownloadErrEmbedData).ok();
                         sleep(Duration::from_secs(5));
                         tx.send(UpdateComponents::DownloadCompleted(None)).ok();
                     }
-                },
-                ResultType::IOERROR | ResultType::FAILURE => {
-                    tx.send(UpdateComponents::DownloadErrDownload).ok();
+                }
+                Err(e) => {
+                    tx.send(UpdateComponents::DownloadErrDownload(e.to_string()))
+                        .ok();
                     sleep(Duration::from_secs(5));
                     tx.send(UpdateComponents::DownloadCompleted(None)).ok();
-                },
+                }
             };
         });
         Ok(())
